Solved Bug 365: Falsche UStVA bei negativem Vorsteuer-Betrag (Teil 2)
[kivitendo-erp.git] / SL / IS.pm
index d4d8c6f..e29f67f 100644 (file)
--- a/SL/IS.pm
+++ b/SL/IS.pm
@@ -304,9 +304,6 @@ sub invoice_details {
 
   $form->{paid} = $form->format_amount($myconfig, $form->{paid}, 2);
 
-  # myconfig variables
-  map { $form->{$_} = $myconfig->{$_} }
-    (qw(company address tel fax signature businessnumber));
   $form->{username} = $myconfig->{name};
 
   $dbh->disconnect;
@@ -360,8 +357,8 @@ sub customer_details {
 
   $ref = $sth->fetchrow_hashref(NAME_lc);
 
-  # remove id and taxincluded before copy back
-  delete @$ref{qw(id taxincluded)};
+  # remove notes, id and taxincluded before copy back
+  delete @$ref{qw(id taxincluded notes)};
   map { $form->{$_} = $ref->{$_} } keys %$ref;
 
   $sth->finish;